@@ -2,4 +2,4 @@
 
 from cconfig import CConfig
 from cmdconfig import CMDConfig
-from typedconfig import TypedConfig
+from typedconfig import TypedConfig, TypedCMDConfig
